:py:mod:`user_input_worker`
===========================

.. py:module:: user_input_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   user_input_worker.initialise
   user_input_worker.start_user_input_capture
   user_input_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   user_input_worker.current_dir
   user_input_worker.current_dir
   user_input_worker.worker_object
   user_input_worker.visualisation_on
   user_input_worker.latest_user_input
   user_input_worker.loop_on
   user_input_worker.finish
   user_input_worker.vis


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: worker_object
   :annotation: :Heron.communication.source_worker.SourceWorker

   

.. py:data:: visualisation_on
   :annotation: :bool

   

.. py:data:: latest_user_input
   :annotation: :str

   

.. py:data:: loop_on
   :annotation: = False

   

.. py:data:: finish
   :annotation: = False

   

.. py:data:: vis
   :annotation: :Heron.gui.visualisation_dpg.VisualisationDPG

   

.. py:function:: initialise(_worker_object)


.. py:function:: start_user_input_capture(_worker_object)


.. py:function:: on_end_of_life()


